%define build_external_fuse 0
%define build_external_fuse 1

# flag to allow local users to mount partitions. This is *really* not a good
# idea, because all users who have access to the device can do whatever they
# want with the data, and it also adds a root setuid binary to your system, so
# use it on your own risk. Refer to
# http://www.tuxera.com/community/ntfs-3g-faq/#useroption for details.
%define allow_unsafe_mount 0
%if %allow_unsafe_mount
# user mount only works if ntfs-3g is using internal fuse library
%define build_external_fuse 0
%endif

%define major	88
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Name:		ntfs-3g
Version:	2017.3.23
Release:	%mkrel 10
Summary:	Read-write ntfs driver
License:	GPLv2+
Group:		System/Base
URL:		http://www.tuxera.com/community/open-source-ntfs-3g/
Source0:	http://tuxera.com/opensource/%{name}_ntfsprogs-%{version}.tgz

BuildRequires:	pkgconfig(libattr)
BuildRequires:	libgcrypt-devel
BuildRequires:	pkgconfig(gnutls)
BuildRequires:  libuuid-devel
%if %build_external_fuse
BuildRequires:	pkgconfig(fuse) >= 2.8
Requires:	fuse >= 2.8
Requires(pre):	fuse >= 2.8
%else
Requires:	kmod(fuse)
%endif
Obsoletes:	ntfsprogs < 2.0.0-11
Provides:	ntfsprogs = %{version}-%{release}
Recommends:	ntfs-3g-system-compression

Patch0:		ntfs-3g_ntfsprogs-2011.10.9-RC-ntfsck-unsupported-return-0.patch
#Allow reading Windows 10 CU written partitions
Patch1:		check-mftmirr.patch
Patch2:		ntfs-3g-big-sectors.patch
# Fix for ntfsclone crash.
# Discussed with upstream developer but not upstream yet, see:
# https://bugzilla.redhat.com/show_bug.cgi?id=1601146#c4
Patch3:		ntfsclone-full-clusters-bz1601146.patch
# Upstream fix for CVE-2019-9755
# https://sourceforge.net/p/ntfs-3g/ntfs-3g/ci/85c1634a26faa572d3c558d4cf8aaaca5202d4e9/
Patch4:		0002-Fixed-reporting-an-error-when-failed-to-build-the-mo.patch

%description
NTFS-3G is a stable, open source, GPL licensed, POSIX, read/write NTFS 
driver for Linux and many other operating systems. It provides safe 
handling of the Windows XP, Windows Server 2003, Windows 2000, Windows 
Vista, Windows Server 2008 and Windows 7 NTFS file systems. NTFS-3G can 
create, remove, rename, move files, directories, hard links, and streams; 
it can read and write normal and transparently compressed files, including 
streams and sparse files; it can handle special files like symbolic links, 
devices, and FIFOs, ACL, extended attributes; moreover it provides full 
file access right and ownership support.

%package	-n %{libname}
Summary:	Library for ntfs-3g
Group:		System/Libraries
Conflicts:	%{name} < 2017.3.23-2

%description	-n %{libname}
This package contains the library needed to run programs dynamically
linked with libntfs-3g.

%package	-n %{develname}
Summary:	Development files and libraries for ntfs-3g
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Obsoletes:	%{_lib}ntfs-devel < 2.0.0-11
Obsoletes:	ntfs-3g-devel < 2017.3.23-2

%description	-n %{develname}
Headers and libraries for developing applications that use ntfs-3g
functionality.

%prep
%setup -qn %{name}_ntfsprogs-%{version}
%autopatch -p1

%build
export CFLAGS="%{optflags} -fPIC"
%configure \
	--disable-static \
	--disable-ldconfig \
%if %build_external_fuse
	--with-fuse=external \
%else
	--with-fuse=internal \
%endif
	--exec-prefix=/ \
	--enable-posix-acls \
	--enable-xattr-mappings \
	--enable-crypto \
	--enable-extras \
	--enable-quarantined

%make_build

%install
sed -i -e 's|/sbin/ldconfig|true|' src/Makefile
%make_install

rm -rf %{buildroot}%{_libdir}/*.la
rm -rf %{buildroot}%{_libdir}/*.a

# make the symlink an actual copy to avoid confusion
rm -rf %{buildroot}/%{_sbindir}/mount.ntfs-3g
cp -a %{buildroot}/%{_bindir}/ntfs-3g %{buildroot}/%{_sbindir}/mount.ntfs-3g

# Actually make some symlinks for simplicity...
# ... since we're obsoleting ntfsprogs-fuse
pushd %{buildroot}/%{_bindir}
ln -s ntfs-3g ntfsmount
popd
pushd %{buildroot}/%{_sbindir}
ln -s mount.ntfs-3g mount.ntfs-fuse
# And since there is no other package in Fedora that provides an ntfs 
# mount...
ln -s mount.ntfs-3g mount.ntfs
# Need this for fsck to find it
ln -s ../bin/ntfsck fsck.ntfs
popd

mv %{buildroot}/sbin/* %{buildroot}/%{_sbindir}
rmdir %{buildroot}/sbin

# We get this on our own, thanks.
rm -rf %{buildroot}%{_defaultdocdir}/%{name}/README


%files
%doc README AUTHORS CREDITS NEWS
%{_bindir}/lowntfs-3g
%{_bindir}/ntfsmount
%{_bindir}/ntfs-3g
%{_bindir}/ntfs-3g.probe
%{_bindir}/ntfscat
%{_bindir}/ntfscluster
%{_bindir}/ntfscmp
%{_bindir}/ntfsfix
%{_bindir}/ntfsinfo
%{_bindir}/ntfsls
%{_bindir}/ntfssecaudit
%{_bindir}/ntfsusermap
# Extras
%{_bindir}/ntfsck
%{_bindir}/ntfsdecrypt
%{_bindir}/ntfsdump_logfile
%{_bindir}/ntfsfallocate
%{_bindir}/ntfsmftalloc
%{_bindir}/ntfsmove
%{_bindir}/ntfsrecover
%{_bindir}/ntfstruncate
%{_bindir}/ntfswipe
%{_sbindir}/fsck.ntfs
%{_sbindir}/mkfs.ntfs
%{_sbindir}/mkntfs
%{_sbindir}/ntfsclone
%{_sbindir}/ntfscp
%{_sbindir}/ntfslabel
%{_sbindir}/ntfsresize
%{_sbindir}/ntfsundelete
%{_mandir}/man8/*
%{_sbindir}/mount.ntfs
%if %allow_unsafe_mount
%attr(4755,root,root) %{_sbindir}/mount.ntfs-3g
%else
%attr(754,root,root) %{_sbindir}/mount.ntfs-3g
%endif
%{_sbindir}/mount.lowntfs-3g
%{_sbindir}/mount.ntfs-fuse

%files -n %{libname}
/%{_libdir}/libntfs-3g.so.%{major}{,.*}

%files -n %{develname}
%doc ChangeLog
/%{_libdir}/libntfs-3g.so
%{_includedir}/ntfs-3g
%{_libdir}/pkgconfig/libntfs-3g.pc


%changelog
* Thu Mar 12 2020 tv <tv> 2017.3.23-10.mga8
+ Revision: 1555870
- enable quarantined ntfsprogs utilities
- BR uuid b/c ntfsprogs DCE compliant UUID generation code requires the uuid library
- enable posix ACLS, enable xattr mappings
- provide a fsck.ntfs symlink
- simplify in a /usrMove world
- update description (also we don't have static libs)

* Thu Mar 12 2020 tv <tv> 2017.3.23-9.mga8
+ Revision: 1555844
- make clear patch 4 is about a CVE
- fix ntfsclone crash (rhbz#1601146)
- support bigger sector sizes on Windows 10
- add Recommends: ntfs-3g-system-compression. That allows people with
  Windows 10 to read system files.

* Sat Feb 15 2020 umeabot <umeabot> 2017.3.23-8.mga8
+ Revision: 1524101
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Mar 26 2019 daviddavid <daviddavid> 2017.3.23-7.mga7
+ Revision: 1380292
- aad debian patch to fix CVE-2019-9755 (mga#24562)

* Sun Sep 23 2018 umeabot <umeabot> 2017.3.23-6.mga7
+ Revision: 1299807
- Mageia 7 Mass Rebuild

* Mon May 21 2018 zezinho <zezinho> 2017.3.23-5.mga7
+ Revision: 1231028
- added patch to read Win10cu written partitons

* Fri Apr 27 2018 wally <wally> 2017.3.23-4.mga7
+ Revision: 1222930
- fix devel pkg requires

* Fri Apr 27 2018 wally <wally> 2017.3.23-3.mga7
+ Revision: 1222929
- fix devel pkg obsoletes
- add conflicts for lib files splitted out from main pkg
- drop provides from lib pkg
- drop old obsoletes

* Fri Apr 27 2018 zezinho <zezinho> 2017.3.23-2.mga7
+ Revision: 1222903
- try to libify the package

* Sat Jul 22 2017 daviddavid <daviddavid> 2017.3.23-1.mga7
+ Revision: 1127812
- new version: 2017.3.23
- remove merged upstream patch

* Fri Feb 03 2017 luigiwalser <luigiwalser> 2016.2.22-4.mga6
+ Revision: 1084635
- add patch to fix CVE-2017-0358

* Mon Mar 21 2016 tv <tv> 2016.2.22-3.mga6
+ Revision: 993635
- adjust file list
- new release

* Tue Jan 12 2016 tv <tv> 2015.3.14-3.mga6
+ Revision: 922266
- rebuild for new gnutls

* Thu Sep 10 2015 fwang <fwang> 2015.3.14-2.mga6
+ Revision: 875429
- rebuild for new libgcrypt

* Sat Aug 15 2015 daviddavid <daviddavid> 2015.3.14-1.mga6
+ Revision: 864887
- new version: 2015.3.14
- add patch from Fedora to fix CVE-2015-3202
- update URL
- enable crypto and extras supports

* Wed Oct 15 2014 umeabot <umeabot> 2014.2.15-4.mga5
+ Revision: 747395
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2014.2.15-3.mga5
+ Revision: 682946
- Mageia 5 Mass Rebuild

* Sun Jun 15 2014 wally <wally> 2014.2.15-2.mga5
+ Revision: 636622
- obsolete also lib and devel pkg from ntfsprogs

* Sat Mar 08 2014 tv <tv> 2014.2.15-1.mga5
+ Revision: 601224
- new release

* Sat Oct 19 2013 umeabot <umeabot> 2013.1.13-3.mga4
+ Revision: 529071
- Mageia 4 Mass Rebuild

* Wed Jul 03 2013 neoclust <neoclust> 2013.1.13-2.mga4
+ Revision: 449888
- apply fixes from upstream for issue with 4K sector drives (bz951603)
  and truncated check for Interix types on a 32-bit CPU (bz958681)
- fix bug preventing reads on compressed files on windows 8 partitions (bz967301)

* Sun May 26 2013 blino <blino> 2013.1.13-1.mga4
+ Revision: 428262
- 2013.1.13

* Sun Feb 24 2013 neoclust <neoclust> 2012.1.15-3.mga3
+ Revision: 400267
- Fix obsoleting as here %%rename does not work ( reported on irc )
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 23 2012 fwang <fwang> 2012.1.15-1.mga2
+ Revision: 200184
- new vesion 2012.1.15

* Mon Dec 05 2011 fwang <fwang> 2011.4.12-3.mga2
+ Revision: 176807
- drop .la file

* Thu Jun 16 2011 tv <tv> 2011.4.12-2.mga2
+ Revision: 108396
- fix file list
- new release (merged with ntfsprogs)

* Thu Mar 03 2011 eandry <eandry> 2011.1.15-1.mga1
+ Revision: 63460
- New version 2011.1.15
- clean spec
- drop hal stuff

* Sat Jan 15 2011 blino <blino> 2010.10.2-2.mga1
+ Revision: 18785
- remove old ldconfig scriptlets and build conditionals
- imported package ntfs-3g

